Index: /main/waeup.sirp/trunk/src/waeup/sirp/browser/pages.py
===================================================================
--- /main/waeup.sirp/trunk/src/waeup/sirp/browser/pages.py	(revision 5999)
+++ /main/waeup.sirp/trunk/src/waeup/sirp/browser/pages.py	(revision 6000)
@@ -155,33 +155,33 @@
         return
         
-class RemoveFormPage(WAeUPPage):
-    grok.require('waeup.manageUniversity')
-    grok.name('remove')
-    grok.template('removesubobjectspage')
-    pnav = 1
-
-    def update(self):
-        warning.need()
-        form = self.request.form
-        if 'CANCEL' in form.keys():
-            self.redirect(self.url(self.context))
-        if not 'REMOVE' in form.keys():
-            return
-        child_id = form['val_id']
-        if not isinstance(child_id, list):
-            child_id = [child_id]
-        deleted = []
-        for id in child_id:
-            try:
-                del self.context[id]
-                deleted.append(id)
-            except:
-                self.flash('Could not delete %s: %s: %s' % (
-                        id, sys.exc_info()[0], sys.exc_info()[1]))
-        if len(deleted):
-            self.flash('Successfully removed: %s' % ', '.join(deleted))
-        # We have to redirect to let flash messages appear immediately...
-        self.redirect(self.url())
-        return
+#class RemoveFormPage(WAeUPPage):
+#    grok.require('waeup.manageUniversity')
+#    grok.name('remove')
+#    grok.template('removesubobjectspage')
+#    pnav = 1
+#
+#    def update(self):
+#        warning.need()
+#        form = self.request.form
+#        if 'CANCEL' in form.keys():
+#            self.redirect(self.url(self.context))
+#        if not 'REMOVE' in form.keys():
+#            return
+#        child_id = form['val_id']
+#        if not isinstance(child_id, list):
+#            child_id = [child_id]
+#        deleted = []
+#        for id in child_id:
+#            try:
+#                del self.context[id]
+#                deleted.append(id)
+#            except:
+#                self.flash('Could not delete %s: %s: %s' % (
+#                        id, sys.exc_info()[0], sys.exc_info()[1]))
+#        if len(deleted):
+#            self.flash('Successfully removed: %s' % ', '.join(deleted))
+#        # We have to redirect to let flash messages appear immediately...
+#        self.redirect(self.url())
+#        return
 
 class AdministrationPage(WAeUPPage):
@@ -846,5 +846,5 @@
     grok.name('index')
     title = 'Academics'
-    label = 'Faculties'
+    label = 'Academic Section'
     pnav = 1
     grok.template('facultypage')
@@ -884,5 +884,5 @@
                                   'in the database')
             return
-        self.redirect(self.url(self.context))
+        self.redirect(self.url(self.context, u'@@manage')+'#tab-1')
         
     @grok.action('Cancel')
@@ -890,10 +890,10 @@
         self.redirect(self.url(self.context))   
 
-class RemoveFacultyFormPage(RemoveFormPage):
-    """ Remove Faculty Page 
-    """
-    grok.context(IFacultyContainer)
-    title = "Remove faculty"
-    pnav = 1
+#class RemoveFacultyFormPage(RemoveFormPage):
+#   """ Remove Faculty Page 
+#    """
+#    grok.context(IFacultyContainer)
+#    title = "Remove faculty"
+#    pnav = 1
 
 #
@@ -953,5 +953,5 @@
                                   'in the database')
             return
-        self.redirect(self.url(self.context, u'@@manage'))
+        self.redirect(self.url(self.context, u'@@manage')+'#tab-2')
         
     @grok.action('Cancel')
@@ -969,4 +969,5 @@
     taboneactions = ['Save','Save and return','Cancel']
     tabtwoactions = ['Add department', 'Remove selected','Cancel']
+    subunits = 'Departments'
 
     form_fields = grok.AutoFields(IFaculty)
@@ -1007,8 +1008,60 @@
         if len(deleted):
             self.flash('Successfully removed: %s' % ', '.join(deleted))
+        self.redirect(self.url(self.context, u'@@manage')+'#tab-2')    
         return       
 
     @grok.action('Add department', validator=NullValidator)
     def addDepartment(self, **data):
+        self.redirect(self.url(self.context, '@@add'))
+        return    
+        
+    @grok.action('Cancel', validator=NullValidator)
+    def cancel(self, **data):
+        self.redirect(self.url(self.context))
+        return
+
+class ManageFacultyContainerFormPage(WAeUPEditFormPage):
+    """Manage the basic properties of a `Faculty` instance.
+    """
+    grok.context(IFacultyContainer)
+    grok.name('manage')
+    grok.require('waeup.manageUniversity')
+    grok.template('facultycontainermanagepage')
+    pnav = 1
+    taboneactions = ['Add faculty', 'Remove selected','Cancel']
+    subunits = 'Faculties'
+    title = 'Academics'
+
+    @property
+    def label(self):
+        return 'Manage academic section'
+        
+    def update(self):
+        tabs.need()
+        #warning.need()
+        return super(ManageFacultyContainerFormPage, self).update()
+
+    # ToDo: Show warning message before deletion
+    @grok.action('Remove selected')
+    def delFaculties(self, **data):
+        form = self.request.form
+        child_id = form['val_id']
+        if not isinstance(child_id, list):
+            child_id = [child_id]
+        deleted = []
+        for id in child_id:
+            try:
+                del self.context[id]
+                deleted.append(id)
+            except:
+                self.flash('Could not delete %s: %s: %s' % (
+                        id, sys.exc_info()[0], sys.exc_info()[1]))
+        if len(deleted):
+            self.flash('Successfully removed: %s' % ', '.join(deleted))
+        self.redirect(self.url(self.context, '@@manage')+'#tab-1')    
+        return       
+
+    @grok.action('Add faculty', validator=NullValidator)
+    def addFaculty(self, **data):
         self.redirect(self.url(self.context, '@@add'))
         return    
Index: /main/waeup.sirp/trunk/src/waeup/sirp/browser/templates/facultycontainermanagepage.pt
===================================================================
--- /main/waeup.sirp/trunk/src/waeup/sirp/browser/templates/facultycontainermanagepage.pt	(revision 6000)
+++ /main/waeup.sirp/trunk/src/waeup/sirp/browser/templates/facultycontainermanagepage.pt	(revision 6000)
@@ -0,0 +1,74 @@
+<h2 i18n:translate=""
+tal:condition="view/label"
+tal:content="view/label">Label</h2>
+
+<div class="form-status"
+tal:define="status view/status"
+tal:condition="status">
+
+<div i18n:translate="" tal:content="view/status">
+  Form status summary
+</div>
+
+<ul class="errors" tal:condition="view/errors">
+  <li tal:repeat="error view/error_views">
+     <span tal:replace="structure error">Error Type</span>
+  </li>
+</ul>
+</div>
+
+
+<form action="." tal:attributes="action request/URL" method="POST"
+      class="edit-form" enctype="multipart/form-data"> 
+
+<div id="tabs">
+<ul>
+  <li><a href="#tab-1"><span tal:content="view/subunits">Contents</span></a></li>
+</ul>
+   
+<div id="tab-1">
+  <h3 tal:content="view/subunits">Faculties</h3>
+  <table class="zebra">
+    <thead>
+      <tr>
+        <th>&nbsp;</th><th>Code</th><th>Title</th>
+      </tr>
+    </thead>
+    <tbody>
+      <tr tal:repeat="dep context/values">
+        <td>
+          <input type="checkbox"
+    		 name="val_id"
+    		 tal:attributes="value dep/code" />
+        </td>
+        <td>
+          <a tal:attributes="href python: view.url(dep)"
+    	     tal:content="dep/__name__">
+        	ID
+          </a>
+        </td>
+        <td>
+          <span tal:content="dep/title">
+    	   ID
+          </span>
+        </td>
+      </tr>
+    </tbody>
+  </table>
+  
+    <div id="actionsView">
+        <span class="actionButtons" tal:condition="view/availableActions">
+            <span tal:repeat="action view/actions"
+                  tal:omit-tag="">
+              <input tal:condition="python:action.label in view.taboneactions"
+                     tal:replace="structure action/render"/>
+            </span>
+        </span>
+    </div>      
+  
+</div>
+</div>
+</form>  
+
+
+
Index: /main/waeup.sirp/trunk/src/waeup/sirp/browser/templates/facultymanagepage.pt
===================================================================
--- /main/waeup.sirp/trunk/src/waeup/sirp/browser/templates/facultymanagepage.pt	(revision 5999)
+++ /main/waeup.sirp/trunk/src/waeup/sirp/browser/templates/facultymanagepage.pt	(revision 6000)
@@ -25,5 +25,5 @@
 <ul>
   <li><a href="#tab-1"><span>Settings</span></a></li>
-  <li><a href="#tab-2"><span>Contents</span></a></li>
+  <li><a href="#tab-2"><span tal:content="view/subunits">Contents</span></a></li>
 </ul>
    
@@ -73,5 +73,5 @@
     
 <div id="tab-2">
-  <h3>Departments</h3>
+  <h3 tal:content="view/subunits">Departments</h3>
   <table class="zebra">
     <thead>
Index: /main/waeup.sirp/trunk/src/waeup/sirp/browser/viewlets.py
===================================================================
--- /main/waeup.sirp/trunk/src/waeup/sirp/browser/viewlets.py	(revision 5999)
+++ /main/waeup.sirp/trunk/src/waeup/sirp/browser/viewlets.py	(revision 6000)
@@ -310,7 +310,14 @@
     grok.view(DatacenterPage)
     text = 'Edit settings'
+
+class ManageFacultyContainerActionButton(ManageActionButton):
+    """ 'Manage settings' button for faculties.
+    """
+    grok.context(IFacultyContainer)
+    grok.view(FacultyContainerPage)
+    text = 'Manage academic section'
     
 class ManageFacultyActionButton(ManageActionButton):
     """ 'Edit settings' button for faculties.
     """
     grok.context(IFaculty)
@@ -356,8 +363,8 @@
     text = 'Add user'
 
-class AddFacultyActionButton(AddActionButton):
-    grok.context(IFacultyContainer)
-    grok.view(FacultyContainerPage)
-    text = 'Add faculty'
+#class AddFacultyActionButton(AddActionButton):
+#    grok.context(IFacultyContainer)
+#    grok.view(FacultyContainerPage)
+#    text = 'Add faculty'
     
 #class AddDepartmentActionButton(AddActionButton):
@@ -392,8 +399,8 @@
 
 
-class RemoveFacultyActionButton(RemoveActionButton):
-    grok.context(IFacultyContainer)
-    grok.view(FacultyContainerPage)
-    text = 'Remove faculty'
+#class RemoveFacultyActionButton(RemoveActionButton):
+#    grok.context(IFacultyContainer)
+#    grok.view(FacultyContainerPage)
+#    text = 'Remove faculty'
    
 #class RemoveDepartmentActionButton(RemoveActionButton):
@@ -310,7 +310,14 @@
     
 class ManageFacultyActionButton(ManageActionButton):
-    """ 'Edit settings' button for faculties.
+    """ 'Manage settings' button for faculties.
     """
     grok.context(IFaculty)
